## FIT REMOTE FUNCTION

- excute_testcase: Send a resquest message to the FIT tool with a list of scenario numbers for fault injection as arguments. 

- is_testcase_result: Takes the fault injection result as an argument and determines whether the fault injection was successfully completed.
